AnimatedBorderRadius class

Constructors

AnimatedBorderRadius.circular(double? radius)
factory
AnimatedBorderRadius.horizontal({double? left, double? right})
factory
AnimatedBorderRadius.only({double? topLeft, double? topRight, double? bottomLeft, double? bottomRight})
factory
AnimatedBorderRadius.vertical({double? top, double? bottom})
factory

Properties

bottomLeft double?
final
bottomRight double?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeft double?
final
topRight double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited