AnimatedBorderSegments class
Constructors
-
AnimatedBorderSegments.alignmentBased(List<
AlignmentBasedBorderSegment> segments) -
factory
-
AnimatedBorderSegments.distanceBased(List<
DistanceBasedBorderSegment> segments) -
factory
-
AnimatedBorderSegments.spacedEvenly(List<
EvenlySpacedBorderSegment> segments) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentationType → SegmentationType
-
final
-
segments
→ List<
BorderSegment> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited