BorderSegment class

Implementers

Constructors

BorderSegment({double initialSize = 220.0, double heightFactor = 0.6, BorderSegmentAlignment? alignment, double position = 0, required Color color})

Properties

alignment BorderSegmentAlignment?
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
heightFactor double
final
initialSize double
final
position double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRadius(double parentHeight) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited