FlutterAnimatedBorder class
Animated Border.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FlutterAnimatedBorder
Constructors
- FlutterAnimatedBorder({Key? key, AnimatedBorderController? controller, bool glow = true, double glowSpread = 3.7, bool clipGlowAtMargin = true, double margin = 8, double borderWidth = 2, AnimatedBorderRadius? borderRadius, Color childBackgroundColor = Colors.white, required Duration duration, bool autoStart = true, required AnimatedBorderSegments animationSegments, AnimatedBorderSegments? reverseAnimationSegments, required Widget child})
Properties
- animationSegments → AnimatedBorderSegments
-
final
- autoStart → bool
-
final
- borderRadius → AnimatedBorderRadius?
-
final
- borderWidth → double
-
final
- child → Widget
-
final
- childBackgroundColor → Color
-
final
- clipGlowAtMargin → bool
-
final
- controller → AnimatedBorderController?
-
final
- duration → Duration
-
final
- glow → bool
-
final
- glowBorderRadius ↔ BorderRadius?
-
latefinal
- glowSpread → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerBorderRadius ↔ BorderRadius?
-
latefinal
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → double
-
final
- outerBorderRadius ↔ BorderRadius?
-
latefinal
- reverseAnimationSegments → AnimatedBorderSegments?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FlutterAnimatedBorder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited